@@ -28,7 +28,7 @@ int ErrMessage(PyMOLGlobals * G, const char *where, const char *what);
 
 #define CHECKOK(ok, var) ok &= var ? true : false;
 
-#define th_raise(x) goto th_except ## x
-#define th_assert(x, c) {if(!(c)) th_raise(x);}
+#define ok_raise(x) goto ok_except ## x
+#define ok_assert(x, c) {if(!(c)) ok_raise(x);}
 
 #endif
