@@ -28,7 +28,7 @@ Z* -------------------------------------------------------------------
 
 /* BEGIN PROPRIETARY CODE SEGMENT (see disclaimer in "os_proprietary.h") */
 #ifdef __WIN32
-PFNGLTEXIMAGE3DPROC getTexImage3D();
+static PFNGLTEXIMAGE3DPROC getTexImage3D;
 static PFNGLTEXIMAGE3DPROC glTexImage3D;
 static PFNGLACTIVETEXTUREPROC glActiveTexture = -100l;
 static PFNGLGENPROGRAMSARBPROC glGenProgramsARB;
@@ -182,6 +182,8 @@ void CShaderMgr_AddVBOsToFree(CShaderMgr * I, GLuint *vboid, int nvbos);
 void CShaderMgr_AddVBOToFree(CShaderMgr * I, GLuint vboid);
 void CShaderMgr_FreeAllVBOs(CShaderMgr * I);
 
+void CShaderPrg_Set_Stereo_And_AnaglyphMode(PyMOLGlobals * G, CShaderPrg * shaderPrg);
+
 CShaderPrg *CShaderPrg_Enable_DefaultShader(PyMOLGlobals * G);
 CShaderPrg *CShaderPrg_Enable_DefaultShaderWithSettings(PyMOLGlobals * G, CSetting * set1, CSetting * set2);
 CShaderPrg *CShaderPrg_Enable_DefaultScreenShader(PyMOLGlobals * G);
