@@ -15,23 +15,19 @@ void PyMOLReadPixels(GLint x,
   GLint skiprows, skippixels, alignment;
 
   /* Save current pixel store state. */
-#ifndef _PYMOL_PURE_OPENGL_ES
   glGetIntegerv(GL_PACK_SWAP_BYTES, &swapbytes);
   glGetIntegerv(GL_PACK_LSB_FIRST, &lsbfirst);
   glGetIntegerv(GL_PACK_ROW_LENGTH, &rowlength);
   glGetIntegerv(GL_PACK_SKIP_ROWS, &skiprows);
   glGetIntegerv(GL_PACK_SKIP_PIXELS, &skippixels);
-#endif
   glGetIntegerv(GL_PACK_ALIGNMENT, &alignment);
 
   /* Set desired pixel store state. */
-#ifndef _PYMOL_PURE_OPENGL_ES
   glPixelStorei(GL_PACK_SWAP_BYTES, GL_FALSE);
   glPixelStorei(GL_PACK_LSB_FIRST, GL_FALSE);
   glPixelStorei(GL_PACK_ROW_LENGTH, 0);
   glPixelStorei(GL_PACK_SKIP_ROWS, 0);
   glPixelStorei(GL_PACK_SKIP_PIXELS, 0);
-#endif
   glPixelStorei(GL_PACK_ALIGNMENT, 1);
 
   /* call glFlush & glFinish first to avoid full system crash on buggy
@@ -49,13 +45,11 @@ void PyMOLReadPixels(GLint x,
   glFinish();
 
   /* and then estore current pixel store state. */
-#ifndef _PYMOL_PURE_OPENGL_ES
   glPixelStorei(GL_PACK_SWAP_BYTES, swapbytes);
   glPixelStorei(GL_PACK_LSB_FIRST, lsbfirst);
   glPixelStorei(GL_PACK_ROW_LENGTH, rowlength);
   glPixelStorei(GL_PACK_SKIP_ROWS, skiprows);
   glPixelStorei(GL_PACK_SKIP_PIXELS, skippixels);
-#endif
   glPixelStorei(GL_PACK_ALIGNMENT, alignment);
 
 }
@@ -70,37 +64,29 @@ void PyMOLDrawPixels(GLsizei width,
   GLint skiprows, skippixels, alignment;
 
   /* Save current pixel store state. */
-#ifndef _PYMOL_PURE_OPENGL_ES
   glGetIntegerv(GL_UNPACK_SWAP_BYTES, &swapbytes);
   glGetIntegerv(GL_UNPACK_LSB_FIRST, &lsbfirst);
   glGetIntegerv(GL_UNPACK_ROW_LENGTH, &rowlength);
   glGetIntegerv(GL_UNPACK_SKIP_ROWS, &skiprows);
   glGetIntegerv(GL_UNPACK_SKIP_PIXELS, &skippixels);
-#endif
   glGetIntegerv(GL_UNPACK_ALIGNMENT, &alignment);
 
   /* Set desired pixel store state. */
-#ifndef _PYMOL_PURE_OPENGL_ES
   glPixelStorei(GL_UNPACK_SWAP_BYTES, GL_FALSE);
   glPixelStorei(GL_UNPACK_LSB_FIRST, GL_FALSE);
   glPixelStorei(GL_UNPACK_ROW_LENGTH, 0);
   glPixelStorei(GL_UNPACK_SKIP_ROWS, 0);
   glPixelStorei(GL_UNPACK_SKIP_PIXELS, 0);
-#endif
   glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
 
-#ifndef _PYMOL_PURE_OPENGL_ES
   glDrawPixels(width, height, format, type, pixels);
-#endif
 
   /* Restore current pixel store state. */
-#ifndef _PYMOL_PURE_OPENGL_ES
   glPixelStorei(GL_UNPACK_SWAP_BYTES, swapbytes);
   glPixelStorei(GL_UNPACK_LSB_FIRST, lsbfirst);
   glPixelStorei(GL_UNPACK_ROW_LENGTH, rowlength);
   glPixelStorei(GL_UNPACK_SKIP_ROWS, skiprows);
   glPixelStorei(GL_UNPACK_SKIP_PIXELS, skippixels);
-#endif
   glPixelStorei(GL_UNPACK_ALIGNMENT, alignment);
 
 }
@@ -110,11 +96,7 @@ int PyMOLCheckOpenGLErr(char *pos)
   int flag = 0;
   GLenum glerr = glGetError();
   while(glerr != GL_NO_ERROR) {
-#ifndef _PYMOL_PURE_OPENGL_ES
     printf("OpenGL-Error: Where? %s: %s\n", pos, (char *) gluErrorString(glerr));
-#else
-    printf("OpenGL-Error: Where? %s: glerr=%d\n", pos, glerr);
-#endif
     glerr = glGetError();
     flag = 1;
   }
