@@ -31,6 +31,7 @@ Z* -------------------------------------------------------------------
 
 #include "Menu.h"
 #include "Executive.h"
+#include "Ortho.h"
 
 struct _CSeq {
   Block *Block;
@@ -293,7 +294,7 @@ static int SeqClick(Block * block, int button, int x, int y, int mod)
   return (1);
 }
 
-static void SeqDraw(Block * block)
+static void SeqDraw(Block * block ORTHOCGOARG)
 {
   PyMOLGlobals *G = block->G;
   register CSeq *I = G->Seq;
@@ -302,23 +303,34 @@ static void SeqDraw(Block * block)
 
     int x = I->Block->rect.left;
     int y = I->Block->rect.bottom + I->ScrollBarMargin + 1;
-    float *bg_color, overlay_color[3] = { 1.0F, 1.0F, 1.0F };
+    float bg_color[3] = { 0.f, 0.f, 0.f }, overlay_color[3] = { 1.0F, 1.0F, 1.0F };
     int label_color_index = SettingGetGlobal_color(G, cSetting_seq_view_label_color);
     float *label_color = ColorGet(G, label_color_index);
     copy3f(label_color, overlay_color);
-    bg_color = SettingGet_3fv(G, NULL, NULL, cSetting_bg_rgb);
-    overlay_color[0] = overlay_color[0] - bg_color[0];
-    overlay_color[1] = overlay_color[1] - bg_color[1];
-    overlay_color[2] = overlay_color[2] - bg_color[2];
-    if(diff3f(overlay_color, bg_color) < 0.25)
-      zero3f(overlay_color);
 
+    if (SettingGetGlobal_b(G, cSetting_bg_gradient)){
+      if(SettingGetGlobal_b(G, cSetting_seq_view_location)) {
+	copy3f(ColorGet(G, SettingGetGlobal_color(G, cSetting_bg_rgb_bottom)), bg_color);
+      } else {
+	copy3f(ColorGet(G, SettingGetGlobal_color(G, cSetting_bg_rgb_top)), bg_color);
+      }      
+    } else {
+      copy3f(ColorGet(G, SettingGetGlobal_color(G, cSetting_bg_rgb)), bg_color);
+    }
+    if(!SettingGetGlobal_b(G, cSetting_seq_view_overlay)) {
+      if (orthoCGO){
+	CGOColorv(orthoCGO, bg_color);
+      } else {
+	glColor3fv(bg_color);
+      }
+      BlockFill(I->Block ORTHOCGOARGVAR);
+    }
     if(I->ScrollBarActive) {
       ScrollBarSetBox(I->ScrollBar, I->Block->rect.bottom + I->ScrollBarWidth,
                       I->Block->rect.left + I->ScrollBarMargin,
                       I->Block->rect.bottom + 2,
                       I->Block->rect.right - I->ScrollBarMargin);
-      ScrollBarDoDraw(I->ScrollBar);
+      ScrollBarDoDraw(I->ScrollBar ORTHOCGOARGVAR);
       y += I->ScrollBarWidth;
       I->NSkip = (int) ScrollBarGetValue(I->ScrollBar);
     } else {
@@ -398,7 +410,7 @@ static void SeqDraw(Block * block)
           pix_wid = I->CharWidth * ch_wid;
           tot_len = col->offset + ch_wid - I->NSkip;
           if(tot_len <= vis_size) {
-            TextDrawSubStrFast(G, row->txt, xx, y1, col->start, ch_wid);
+            TextDrawSubStrFast(G, row->txt, xx, y1, col->start, ch_wid ORTHOCGOARGVAR);
           }
         }
         y1 += I->LineHeight;
@@ -408,11 +420,11 @@ static void SeqDraw(Block * block)
       for(a = I->NRow - 1; a >= 0; a--) {
         row = I->Row + a;
         cur_color = overlay_color;
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
-        glColor3fv(cur_color);
-#endif
+	if (orthoCGO){
+	  CGOColorv(orthoCGO, cur_color);
+	} else {
+	  glColor3fv(cur_color);
+	}
         yy = y1 - 2;
         if(max_len < row->ext_len)
           max_len = row->ext_len;
@@ -440,11 +452,11 @@ static void SeqDraw(Block * block)
             if(tot_len <= vis_size) {
               if(row->label_flag) {
                 TextSetColor(G, cur_color);
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
-                glColor3fv(cur_color);
-#endif
+		if (orthoCGO){
+		  CGOColorv(orthoCGO, cur_color);
+		} else {
+		  glColor3fv(cur_color);
+		}
               } else if(col->unaligned && unaligned_color) {
                 float tmp_color[3];
                 float *v = ColorGet(G, col->color);
@@ -453,69 +465,59 @@ static void SeqDraw(Block * block)
                 case 4:
                   average3f(v, bg_color, tmp_color);
                   TextSetColor(G, tmp_color);
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
-                  glColor3fv(tmp_color);
-#endif
+		  if (orthoCGO){
+		    CGOColorv(orthoCGO, tmp_color);
+		  } else {
+		    glColor3fv(tmp_color);
+		  }
                   break;
                 case 2:
                 case 5:
                   average3f(v, unaligned_color, tmp_color);
                   TextSetColor(G, tmp_color);
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
-                  glColor3fv(tmp_color);
-#endif
+		  if (orthoCGO){
+		    CGOColorv(orthoCGO, tmp_color);
+		  } else {
+		    glColor3fv(tmp_color);
+		  }
                   break;
                 default:
                   TextSetColor(G, unaligned_color);
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
-                 glColor3fv(unaligned_color);
-#endif
+		  if (orthoCGO){
+		    CGOColorv(orthoCGO, unaligned_color);
+		  } else {
+		    glColor3fv(unaligned_color);
+		  }
                   break;
                 }
               } else {
                 float *v = ColorGet(G, col->color);
                 TextSetColor(G, v);
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
-                glColor3fv(v);
-#endif
+		if (orthoCGO){
+		  CGOColorv(orthoCGO, v);
+		} else {
+		  glColor3fv(v);
+		}
               }
               if(col->inverse) {
-#ifdef PURE_OPENGL_ES_2
-    /* TODO */
-#else
-#ifdef _PYMOL_GL_DRAWARRAYS
-		{
-		  const GLint polyVerts[] = {
-		    xx, yy,
-		    xx, yy + I->LineHeight - 1,
-		    xx + pix_wid, yy,
-		    xx + pix_wid, yy + I->LineHeight - 1
-		  };
-		  glEnableClientState(GL_VERTEX_ARRAY);
-		  glVertexPointer(2, GL_INT, 0, polyVerts);
-		  glDrawArrays(GL_TRIANGLE_STRIP, 0, 4);
-		  glDisableClientState(GL_VERTEX_ARRAY);
+		if (orthoCGO){
+		  CGOBegin(orthoCGO, GL_TRIANGLE_STRIP);
+		  CGOVertex(orthoCGO, xx, yy, 0.f);
+		  CGOVertex(orthoCGO, xx, yy + I->LineHeight - 1, 0.f);
+		  CGOVertex(orthoCGO, xx + pix_wid, yy, 0.f);
+		  CGOVertex(orthoCGO, xx + pix_wid, yy + I->LineHeight - 1, 0.f);
+		  CGOEnd(orthoCGO);
+		} else {
+		  glBegin(GL_POLYGON);
+		  glVertex2i(xx, yy);
+		  glVertex2i(xx, yy + I->LineHeight - 1);
+		  glVertex2i(xx + pix_wid, yy + I->LineHeight - 1);
+		  glVertex2i(xx + pix_wid, yy);
+		  glEnd();
 		}
-#else
-                glBegin(GL_POLYGON);
-                glVertex2i(xx, yy);
-                glVertex2i(xx, yy + I->LineHeight - 1);
-                glVertex2i(xx + pix_wid, yy + I->LineHeight - 1);
-                glVertex2i(xx + pix_wid, yy);
-                glEnd();
-#endif
-#endif
                 TextSetColor(G, black);
               }
-              TextDrawSubStrFast(G, row->txt, xx, y1, col->start, ch_wid);
+              TextDrawSubStrFast(G, row->txt, xx, y1, col->start, ch_wid ORTHOCGOARGVAR);
             }
           }
         }
@@ -533,7 +535,7 @@ static void SeqDraw(Block * block)
               pix_wid = I->CharWidth * ch_wid;
               tot_len = col->offset + ch_wid - I->NSkip;
               if(tot_len <= vis_size) {
-                TextDrawCharRepeat(G, fill_char, xx, y1, col->start, ch_wid);
+                TextDrawCharRepeat(G, fill_char, xx, y1, col->start, ch_wid ORTHOCGOARGVAR);
               }
             }
           }
@@ -575,34 +577,26 @@ static void SeqDraw(Block * block)
             xx2 =
               x + I->CharMargin + I->CharWidth * (col2->offset +
                                                   (col2->stop - col2->start) - I->NSkip);
-#ifdef PURE_OPENGL_ES_2
-    /* TODO */
-#else
-            glColor3fv(overlay_color);
-#ifdef _PYMOL_GL_DRAWARRAYS
-	    {
-	      const GLint lineVerts[] = {
-		xx, yy,
-		xx, yy + I->LineHeight - 2,
-		xx2, yy + I->LineHeight - 2,
-		xx2, yy
-	      };
-	      glEnableClientState(GL_VERTEX_ARRAY);
-	      glVertexPointer(2, GL_INT, 0, lineVerts);
-	      glDrawArrays(GL_LINE_LOOP, 0, 4);
-	      glDisableClientState(GL_VERTEX_ARRAY);
+	    if (orthoCGO){
+	      CGOColorv(orthoCGO, overlay_color);
+	      CGOLineAsTriangleStrips(orthoCGO, xx, yy, xx2, yy + I->LineHeight - 2);
+	      /* TODO: need to convert to triangles
+	      CGOBegin(orthoCGO, GL_LINE_LOOP);
+	      CGOVertex(orthoCGO, xx, yy);
+	      CGOVertex(orthoCGO, xx, yy + I->LineHeight - 2);
+	      CGOVertex(orthoCGO, xx2, yy + I->LineHeight - 2);
+	      CGOVertex(orthoCGO, xx2, yy);
+	      CGOEnd(orthoCGO);*/
+	    } else {
+	      glBegin(GL_LINE_LOOP);
+	      glVertex2i(xx, yy);
+	      glVertex2i(xx, yy + I->LineHeight - 2);
+	      glVertex2i(xx2, yy + I->LineHeight - 2);
+	      glVertex2i(xx2, yy);
+	      glEnd();
 	    }
-#else
-            glBegin(GL_LINE_LOOP);
-            glVertex2i(xx, yy);
-            glVertex2i(xx, yy + I->LineHeight - 2);
-            glVertex2i(xx2, yy + I->LineHeight - 2);
-            glVertex2i(xx2, yy);
-            glEnd();
-#endif
-#endif
-          }
-        }
+	  }
+	}
       }
       if(I->ScrollBarActive) {
         int real_count = n_real;
@@ -647,32 +641,23 @@ static void SeqDraw(Block * block)
                   stop = cent + 0.5F;
                 }
 
-#ifdef PURE_OPENGL_ES_2
-    /* TODO */
-#else
-                glColor3fv(cur_color);
-#ifdef _PYMOL_GL_DRAWARRAYS
-		{
-		  const GLfloat polyVerts[] = {
-		    start, bot,
-		    start, top,
-		    stop, bot,
-		    stop, top
-		  };
-		  glEnableClientState(GL_VERTEX_ARRAY);
-		  glVertexPointer(2, GL_FLOAT, 0, polyVerts);
-		  glDrawArrays(GL_TRIANGLE_STRIP, 0, 4);
-		  glDisableClientState(GL_VERTEX_ARRAY);
+		if (orthoCGO){
+		  CGOColorv(orthoCGO, cur_color);
+		  CGOBegin(orthoCGO, GL_TRIANGLE_STRIP);
+		  CGOVertex(orthoCGO, start, bot, 0.f);
+		  CGOVertex(orthoCGO, start, top, 0.f);
+		  CGOVertex(orthoCGO, stop, bot, 0.f);
+		  CGOVertex(orthoCGO, stop, top, 0.f);
+		  CGOEnd(orthoCGO);
+		} else {
+		  glColor3fv(cur_color);
+		  glBegin(GL_POLYGON);
+		  glVertex2f(start, bot);
+		  glVertex2f(start, top);
+		  glVertex2f(stop, top);
+		  glVertex2f(stop, bot);
+		  glEnd();
 		}
-#else
-                glBegin(GL_POLYGON);
-                glVertex2f(start, bot);
-                glVertex2f(start, top);
-                glVertex2f(stop, top);
-                glVertex2f(stop, bot);
-                glEnd();
-#endif
-#endif
                 mode = 0;
               } else if(col->inverse && mode) {
                 if(last_color != col->color) {
@@ -687,32 +672,23 @@ static void SeqDraw(Block * block)
                     start = cent - 0.5F;
                     stop = cent + 0.5F;
                   }
-#ifdef PURE_OPENGL_ES_2
-    /* TODO */
-#else
-                  glColor3fv(cur_color);
-#ifdef _PYMOL_GL_DRAWARRAYS
-		  {
-		    const GLfloat polyVerts[] = {
-		      start, bot,
-		      start, top,
-		      stop, bot,
-		      stop, top
-		    };
-		    glEnableClientState(GL_VERTEX_ARRAY);
-		    glVertexPointer(2, GL_FLOAT, 0, polyVerts);
-		    glDrawArrays(GL_TRIANGLE_STRIP, 0, 4);
-		    glDisableClientState(GL_VERTEX_ARRAY);
+		  if (orthoCGO){
+		    CGOColorv(orthoCGO, cur_color);
+		    CGOBegin(orthoCGO, GL_TRIANGLE_STRIP);
+		    CGOVertex(orthoCGO, start, bot, 0.f);
+		    CGOVertex(orthoCGO, start, top, 0.f);
+		    CGOVertex(orthoCGO, stop, bot, 0.f);
+		    CGOVertex(orthoCGO, stop, top, 0.f);
+		    CGOEnd(orthoCGO);
+		  } else {
+		    glColor3fv(cur_color);
+		    glBegin(GL_POLYGON);
+		    glVertex2f(start, bot);
+		    glVertex2f(start, top);
+		    glVertex2f(stop, top);
+		    glVertex2f(stop, bot);
+		    glEnd();
 		  }
-#else
-                  glBegin(GL_POLYGON);
-                  glVertex2f(start, bot);
-                  glVertex2f(start, top);
-                  glVertex2f(stop, top);
-                  glVertex2f(stop, bot);
-                  glEnd();
-#endif
-#endif
                   start = (width * col->offset) / max_len;
                   last_color = col->color;
                   if(row->label_flag)
@@ -732,38 +708,28 @@ static void SeqDraw(Block * block)
                 start = cent - 0.5F;
                 stop = cent + 0.5F;
               }
-#ifdef PURE_OPENGL_ES_2
-    /* TODO */
-#else
-              glColor3fv(cur_color);
-#ifdef _PYMOL_GL_DRAWARRAYS
-	      {
-		const GLfloat polyVerts[] = {
-		  start, bot,
-		  start, top,
-		  stop, bot,
-		  stop, top
-		};
-		glEnableClientState(GL_VERTEX_ARRAY);
-		glVertexPointer(2, GL_FLOAT, 0, polyVerts);
-		glDrawArrays(GL_TRIANGLE_STRIP, 0, 4);
-		glDisableClientState(GL_VERTEX_ARRAY);
+	      if (orthoCGO){
+		CGOColorv(orthoCGO, cur_color);
+		CGOBegin(orthoCGO, GL_TRIANGLE_STRIP);
+		CGOVertex(orthoCGO, start, bot, 0.f);
+		CGOVertex(orthoCGO, start, top, 0.f);
+		CGOVertex(orthoCGO, stop, bot, 0.f);
+		CGOVertex(orthoCGO, stop, top, 0.f);
+		CGOEnd(orthoCGO);
+	      } else {
+		glColor3fv(cur_color);
+		glBegin(GL_POLYGON);
+		glVertex2f(start, bot);
+		glVertex2f(start, top);
+		glVertex2f(stop, top);
+		glVertex2f(stop, bot);
+		glEnd();
 	      }
-#else
-              glBegin(GL_POLYGON);
-              glVertex2f(start, bot);
-              glVertex2f(start, top);
-              glVertex2f(stop, top);
-              glVertex2f(stop, bot);
-              glEnd();
-#endif
-#endif
-            }
-
+	    }
           }
         }
 
-        ScrollBarDrawHandle(I->ScrollBar, 0.35F);
+        ScrollBarDrawHandle(I->ScrollBar, 0.35F ORTHOCGOARGVAR);
       }
     }
   }
