@@ -24,7 +24,6 @@ Z* -------------------------------------------------------------------
 typedef struct {
   PyMOLGlobals *G;
   CCrystal *Crystal;
-  WordType PDBSpaceGroup;
   int PDBZValue;
   WordType SpaceGroup;
   ov_size NSymMat;
@@ -36,10 +35,12 @@ typedef struct {
 
 int SymmetryAttemptGeneration(CSymmetry * I, int quiet);
 void SymmetryFree(CSymmetry * I);
+void SymmetryClear(CSymmetry * I);
 CSymmetry *SymmetryNew(PyMOLGlobals * G);
 void SymmetryUpdate(CSymmetry * I);
 void SymmetryDump(CSymmetry * I);
 CSymmetry *SymmetryCopy(CSymmetry * other);
+CSymmetry *SymmetryCopyTo(CSymmetry * other,CSymmetry *dest);
 PyObject *SymmetryAsPyList(CSymmetry * I);
 int SymmetryFromPyList(CSymmetry * I, PyObject * list);
 CSymmetry *SymmetryNewFromPyList(PyMOLGlobals * G, PyObject * list);
