@@ -76,26 +76,6 @@ static PyObject *ObjectSurfaceStateAsPyList(ObjectSurfaceState * I)
   PyList_SetItem(result, 15, PyInt_FromLong(I->Side));
   PyList_SetItem(result, 16, PyInt_FromLong(I->quiet));
 
-#if 0
-  ObjectNameType MapName;
-  int MapState;
-  CCrystal Crystal;
-  int Active;
-  int *N;
-  float *V;
-  int Range[6];
-  float ExtentMin[3], ExtentMax[3];
-  int ExtentFlag;
-  float Level, Radius;
-  int RefreshFlag;
-  int ResurfaceFlag;
-  float *AtomVertex;
-  int CarveFlag;
-  float CarveBuffer;
-  int DotFlag;
-  CGO *UnitCellCGO;
-#endif
-
   return (PConvAutoNone(result));
 }
 
@@ -705,6 +685,10 @@ static void ObjectSurfaceUpdate(ObjectSurface * I)
           ms->RecolorFlag = false;
         }
       }
+      if (ms->shaderCGO){
+        CGOFree(ms->shaderCGO);
+        ms->shaderCGO = NULL;
+      }
     }
   }
   if(!I->Obj.ExtentFlag) {
@@ -713,17 +697,6 @@ static void ObjectSurfaceUpdate(ObjectSurface * I)
   SceneInvalidate(I->Obj.G);
 }
 
-#if 0
-static int ZOrderFn(float *array, int l, int r)
-{
-  return (array[l] <= array[r]);
-}
-
-static int ZRevOrderFn(float *array, int l, int r)
-{
-  return (array[l] >= array[r]);
-}
-#endif
 static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 {
   PyMOLGlobals *G = I->Obj.G;
@@ -757,7 +730,7 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
       ms = I->State + a;
     } else {
       if(!ms) {
-        if(I->NState && ((SettingGet(G, cSetting_static_singletons) && (I->NState == 1))))
+        if(I->NState && ((SettingGetGlobal_b(G, cSetting_static_singletons) && (I->NState == 1))))
           ms = I->State;
       }
     }
@@ -862,9 +835,9 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
             int render_now = false;
             int t_mode;
 	    short use_shader, generate_shader_cgo = 0, use_display_lists = 0;
-	    use_shader = (int) SettingGet(G, cSetting_surface_use_shader) & 
-	      (int) SettingGet(G, cSetting_use_shaders);
-	    use_display_lists = (int) SettingGet(G, cSetting_use_display_lists);
+	    use_shader = SettingGetGlobal_b(G, cSetting_surface_use_shader) & 
+	                 SettingGetGlobal_b(G, cSetting_use_shaders);
+	    use_display_lists = SettingGetGlobal_i(G, cSetting_use_display_lists);
 
             t_mode = SettingGet_i(G, NULL, I->Obj.Setting, cSetting_transparency_mode);
 
@@ -922,11 +895,7 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 		} else {
 		  CShaderPrg * shaderPrg = 0;
 		  shaderPrg = CShaderPrg_Enable_DefaultShader(G);
-#ifdef PURE_OPENGL_ES_2
-		  CShaderPrg_Set1i(shaderPrg, "lighting_enabled", 0);
-#else
 		  CShaderPrg_Set1i(shaderPrg, "lighting_enabled", 1);
-#endif
 		  
 		  ms->shaderCGO->enable_shaders = shaderPrg ? 0 : 1;
 		  CGORenderGL(ms->shaderCGO, NULL, NULL, NULL, info, NULL);
@@ -958,11 +927,7 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 		}
 		CGOColorv(ms->shaderCGO, col);
 	      } else {
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
 		glColor4f(col[0], col[1], col[2], alpha);
-#endif
 	      }
 
                 if(n && v && I->Obj.RepVis[cRepSurface]) {
@@ -979,11 +944,7 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
                       float sum[3];
                       float matrix[16];
                       int parity;
-#ifdef PURE_OPENGL_ES_2
-    /* TODO */
-#else
                       glGetFloatv(GL_MODELVIEW_MATRIX, matrix);
-#endif
                       t_buf = Alloc(float *, ms->nT * 9);
                       vc = ms->VC;
 
@@ -1070,9 +1031,6 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 			}
 			CGOColorv(ms->shaderCGO, col);
 		      } else {
-#ifdef PURE_OPENGL_ES_2
-    /* TODO */
-#else
 			glColor4f(col[0], col[1], col[2], alpha);
 		      }
 
@@ -1192,7 +1150,6 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 			  glVertex3fv(*(tb++));
 			}
 			glEnd();
-#endif
 #endif
 		      }
 
@@ -1263,9 +1220,6 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 			} else {
 			  while(*n) {
 			    c = *(n++);
-#ifdef PURE_OPENGL_ES_2
-    /* TODO */
-#else
 #ifdef _PYMOL_GL_DRAWARRAYS
 			    {
 			      int nverts = c/2, pl = 0, plc = 0;;
@@ -1317,7 +1271,6 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 			      c -= 2;
 			    }
 			    glEnd();
-#endif
 #endif
 			  }
                         }
@@ -1385,9 +1338,6 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 			switch (ms->Mode) {
 			case 3:
 			case 2:
-#ifdef PURE_OPENGL_ES_2
-			  /* TODO */
-#else
 #ifdef _PYMOL_GL_DRAWARRAYS
 			  {
 			    int nverts = c/2, pl = 0, plc = 0;
@@ -1438,13 +1388,9 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 			    c -= 2;
 			  }
 			  glEnd();
-#endif
 #endif
 			  break;
 			case 1:
-#ifdef PURE_OPENGL_ES_2
-			  /* TODO */
-#else
 #ifdef _PYMOL_GL_DRAWARRAYS
 			  {
 			    int nverts = c, pl = 0, plc = 0;
@@ -1486,14 +1432,10 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 			    c--;
 			  }
 			  glEnd();
-#endif
 #endif
 			  break;
 			case 0:
 			default:
-#ifdef PURE_OPENGL_ES_2
-			  /* TODO */
-#else
 #ifdef _PYMOL_GL_DRAWARRAYS
 			  {
 			    int nverts = c, pl = 0, plc = 0;
@@ -1536,7 +1478,6 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 			    c--;
 			  }
 			  glEnd();
-#endif
 #endif
 			  break;
 			}
@@ -1572,11 +1513,7 @@ static void ObjectSurfaceRender(ObjectSurface * I, RenderInfo * info)
 		  {
 		    CShaderPrg * shaderPrg = 0;
 		    shaderPrg = CShaderPrg_Enable_DefaultShader(G);
-#ifdef PURE_OPENGL_ES_2
-		    CShaderPrg_Set1i(shaderPrg, "lighting_enabled", 0);
-#else
 		    CShaderPrg_Set1i(shaderPrg, "lighting_enabled", 1);
-#endif
 		    ms->shaderCGO->enable_shaders = shaderPrg ? 0 : 1;
 		    CGORenderGL(ms->shaderCGO, NULL, NULL, NULL, info, NULL);
 		    if (shaderPrg)
@@ -1613,7 +1550,7 @@ ObjectSurface *ObjectSurfaceNew(PyMOLGlobals * G)
   ObjectInit(G, (CObject *) I);
 
   I->NState = 0;
-  I->State = VLAMalloc(10, sizeof(ObjectSurfaceState), 5, true);        /* autozero important */
+  I->State = VLACalloc(ObjectSurfaceState, 10);        /* autozero important */
 
   I->Obj.type = cObjectSurface;
 
