@@ -64,6 +64,10 @@ void RepMeshInit(void)
 
 void RepMeshFree(RepMesh * I)
 {
+  if (I->shaderCGO){
+    CGOFree(I->shaderCGO);
+    I->shaderCGO = 0;
+  }
   FreeP(I->VC);
   VLAFreeP(I->V);
   VLAFreeP(I->N);
@@ -88,6 +92,7 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
   float line_width = SceneGetDynamicLineWidth(info, I->Width);
   float mesh_width = SettingGet_f(G, I->R.obj->Setting, NULL, cSetting_mesh_width);
   short dot_as_spheres = I->mesh_type==1 && SettingGet_i(G, I->R.cs->Setting, I->R.obj->Setting, cSetting_dot_as_spheres);
+  int ok = true;
 
   if(ray) {
     if(n) {
@@ -109,20 +114,20 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
       ray->fColor3fv(ray, ColorGet(G, I->R.obj->Color));
       switch (I->mesh_type) {
       case 0:
-        while(*n) {
+        while(ok && *n) {
           c = *(n++);
           if(c--) {
             vc += 3;
             v += 3;
             if(I->oneColorFlag) {
-              while(c--) {
-                ray->fSausage3fv(ray, v - 3, v, radius, col, col);
+              while(ok && c--) {
+                ok &= ray->fSausage3fv(ray, v - 3, v, radius, col, col);
                 v += 3;
                 vc += 3;
               }
             } else {
-              while(c--) {
-                ray->fSausage3fv(ray, v - 3, v, radius, vc - 3, vc);
+              while(ok && c--) {
+                ok &= ray->fSausage3fv(ray, v - 3, v, radius, vc - 3, vc);
                 v += 3;
                 vc += 3;
               }
@@ -130,19 +135,19 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
           }
         }
       case 1:
-        while(*n) {
+        while(ok && *n) {
           c = *(n++);
           if(I->oneColorFlag) {
             ray->fColor3fv(ray, col);
-            while(c--) {
-              ray->fSphere3fv(ray, v, radius);
+            while(ok && c--) {
+              ok &= ray->fSphere3fv(ray, v, radius);
               v += 3;
               vc += 3;
             }
           } else {
-            while(c--) {
+            while(ok && c--) {
               ray->fColor3fv(ray, vc);
-              ray->fSphere3fv(ray, v, radius);
+              ok &= ray->fSphere3fv(ray, v, radius);
               v += 3;
               vc += 3;
             }
@@ -153,15 +158,16 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
     }
   } else if(G->HaveGUI && G->ValidContext) {
     if(pick) {
+      /* no picking meshes */
     } else {
       short use_shader, generate_shader_cgo = 0, use_display_lists;
       short mesh_as_cylinders ;
       int lighting =
         SettingGet_i(G, I->R.cs->Setting, I->R.obj->Setting, cSetting_mesh_lighting);
-      use_shader = (int) SettingGet(G, cSetting_mesh_use_shader) & 
-                           (int) SettingGet(G, cSetting_use_shaders);
-      use_display_lists = (int) SettingGet(G, cSetting_use_display_lists);
-      mesh_as_cylinders = (int) SettingGet(G, cSetting_render_as_cylinders) && SettingGet(G, cSetting_mesh_as_cylinders) && I->mesh_type!=1;
+      use_shader = SettingGetGlobal_b(G, cSetting_mesh_use_shader) & 
+                   SettingGetGlobal_b(G, cSetting_use_shaders);
+      use_display_lists = SettingGetGlobal_i(G, cSetting_use_display_lists);
+      mesh_as_cylinders = SettingGetGlobal_b(G, cSetting_render_as_cylinders) && SettingGetGlobal_b(G, cSetting_mesh_as_cylinders) && I->mesh_type!=1;
 
       if (I->shaderCGO && !use_shader){
 	CGOFree(I->shaderCGO);
@@ -176,9 +182,11 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
       if (use_shader){
 	if (!I->shaderCGO){
 	  I->shaderCGO = CGONew(G);
-	  I->shaderCGO->use_shader = true;
+	  CHECKOK(ok, I->shaderCGO);
+	  if (ok)
+	    I->shaderCGO->use_shader = true;
 	  generate_shader_cgo = 1;
-	} else {
+	} else if (ok) {
 	  CShaderPrg *shaderPrg;
 	  if (dot_as_spheres){
 	    float pixel_scale_value = SettingGetGlobal_f(G, cSetting_ray_pixel_scale);
@@ -186,7 +194,7 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
 	    if(pixel_scale_value < 0)
 	      pixel_scale_value = 1.0F;    
 	    radius = info->vertex_scale * pixel_scale_value * line_width/ 2.f;
-	    shaderPrg = CShaderPrg_Enable_SphereShader(G, "sphere");
+	    shaderPrg = CShaderPrg_Enable_DefaultSphereShader(G);
 	    CShaderPrg_Set1f(shaderPrg, "sphere_size_scale", radius);
 	  } else {
 	    if (mesh_as_cylinders){
@@ -194,24 +202,24 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
 	      CShaderPrg_Set1f(shaderPrg, "uni_radius", SceneGetLineWidthForCylinders(G, info, mesh_width));
 	    } else {
 	      shaderPrg = CShaderPrg_Enable_DefaultShader(G);
-	      CShaderPrg_Set1i(shaderPrg, "lighting_enabled", 0);
+	      CShaderPrg_SetLightingEnabled(shaderPrg, 0);
 	    }
 	  }
+	  if (!shaderPrg) return;
 	  CGORenderGL(I->shaderCGO, NULL, NULL, NULL, info, &I->R);
 	  CShaderPrg_Disable(shaderPrg);
 	  return;
 	}
       }
 
-      if (generate_shader_cgo){
-	CGOResetNormal(I->shaderCGO, true);
-      } else {
-	SceneResetNormal(G, true);
+      if (ok){
+	if (generate_shader_cgo){
+	  ok &= CGOResetNormal(I->shaderCGO, true);
+	} else {
+	  SceneResetNormal(G, true);
+	}
       }
 
-#ifdef PURE_OPENGL_ES_2
-    /* TODO */
-#else
       if(!lighting) {
         if(!info->line_lighting){
 	  if (generate_shader_cgo){
@@ -221,15 +229,16 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
 	  }
 	}
       }
-#endif
       if (generate_shader_cgo){
-	switch (I->mesh_type) {
-	case 0:
-	  CGOLinewidthSpecial(I->shaderCGO, LINEWIDTH_DYNAMIC_WITH_SCALE);
-	  break;
-	case 1:
-	  CGOLinewidthSpecial(I->shaderCGO, POINTSIZE_DYNAMIC_DOT_WIDTH);
-	  break;
+	if (ok){
+	  switch (I->mesh_type) {
+	  case 0:
+	    ok &= CGOLinewidthSpecial(I->shaderCGO, LINEWIDTH_DYNAMIC_MESH);
+	    break;
+	  case 1:
+	    ok &= CGOLinewidthSpecial(I->shaderCGO, POINTSIZE_DYNAMIC_DOT_WIDTH);
+	    break;
+	  }
 	}
       } else {
 	switch (I->mesh_type) {
@@ -265,10 +274,12 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
       }
 #endif
 
-      if (generate_shader_cgo){
-	CGOResetNormal(I->shaderCGO, false);
-      } else {
-	SceneResetNormal(G, false);
+      if (ok){
+	if (generate_shader_cgo){
+	  ok &= CGOResetNormal(I->shaderCGO, false);
+	} else {
+	  SceneResetNormal(G, false);
+	}
       }
 
 #ifdef _PYMOL_GL_CALLLISTS
@@ -286,87 +297,87 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
       case 0:
 	if(n) {
 	  if (generate_shader_cgo){
-	    if(I->oneColorFlag) {
-	      while(*n) {
-		CGOColorv(I->shaderCGO, ColorGet(G, I->oneColor));
-		c = *(n++);
-		if (mesh_as_cylinders){
-		  float *origin = 0, axis[3];
-		  if (c--){
-		    origin = v;
-		    v += 3;
-		  }
-		  while(c--) {
-		    axis[0] = v[0] - origin[0];
-		    axis[1] = v[1] - origin[1];
-		    axis[2] = v[2] - origin[2];
-		    CGOShaderCylinder(I->shaderCGO, origin, axis, 1.f, 15);
-		    origin = v;
-		    v += 3;
-		  }
-
-		} else {
-		  CGOBegin(I->shaderCGO, GL_LINE_STRIP);
-		  while(c--) {
-		    CGOVertexv(I->shaderCGO, v);
-		    v += 3;
-		  }
-		  CGOEnd(I->shaderCGO);
-		}
-	      }
-	    } else {
-	      while(*n) {
-		c = *(n++);
-		if (mesh_as_cylinders){
-		  float *origin = 0, axis[3], *color = 0;
-		  if (c--){
-		    CGOColorv(I->shaderCGO, vc);
-		    color = vc;
-		    origin = v;
-		    vc += 3;
-		    v += 3;
-		  }
-		  while(c--) {
-		    axis[0] = v[0] - origin[0];
-		    axis[1] = v[1] - origin[1];
-		    axis[2] = v[2] - origin[2];
-		    if (*(color) != *(vc) || *(color+1) != *(vc+1) || *(color+2) != *(vc+2)){
-		      CGOShaderCylinder2ndColor(I->shaderCGO, origin, axis, 1.f, 15, vc);
+	    if (ok){
+	      if(I->oneColorFlag) {
+		while(ok && *n) {
+		  ok &= CGOColorv(I->shaderCGO, ColorGet(G, I->oneColor));
+		  if (ok){
+		    c = *(n++);
+		    if (mesh_as_cylinders){
+		      float *origin, axis[3];
+		      if (c--){
+			origin = v;
+			v += 3;
+		      }
+		      while(ok && c--) {
+			axis[0] = v[0] - origin[0];
+			axis[1] = v[1] - origin[1];
+			axis[2] = v[2] - origin[2];
+			ok &= CGOShaderCylinder(I->shaderCGO, origin, axis, 1.f, 15);
+			origin = v;
+			v += 3;
+		      }
 		    } else {
-		      CGOShaderCylinder(I->shaderCGO, origin, axis, 1.f, 15);
+		      ok &= CGOBegin(I->shaderCGO, GL_LINE_STRIP);
+		      while(ok && c--) {
+			ok &= CGOVertexv(I->shaderCGO, v);
+			v += 3;
+		      }
+		      if (ok)
+			ok &= CGOEnd(I->shaderCGO);
 		    }
-		    origin = v;
-		    v += 3;
-		    if (c){
-		      CGOColorv(I->shaderCGO, vc);
+		  }
+		}
+	      } else {
+		while(ok && *n) {
+		  c = *(n++);
+		  if (mesh_as_cylinders){
+		    float *origin, axis[3], *color;
+		    if (c--){
+		      ok &= CGOColorv(I->shaderCGO, vc);
 		      color = vc;
+		      origin = v;
+		      vc += 3;
+		      v += 3;
 		    }
-		    vc += 3;
+		    while(ok && c--) {
+		      axis[0] = v[0] - origin[0];
+		      axis[1] = v[1] - origin[1];
+		      axis[2] = v[2] - origin[2];
+		      if (*(color) != *(vc) || *(color+1) != *(vc+1) || *(color+2) != *(vc+2)){
+			ok &= CGOShaderCylinder2ndColor(I->shaderCGO, origin, axis, 1.f, 15, vc);
+		      } else {
+			ok &= CGOShaderCylinder(I->shaderCGO, origin, axis, 1.f, 15);
+		      }
+		      origin = v;
+		      v += 3;
+		      if (c){
+			ok &= CGOColorv(I->shaderCGO, vc);
+			color = vc;
+		      }
+		      vc += 3;
+		    }
+		  } else {
+		    ok &= CGOBegin(I->shaderCGO, GL_LINE_STRIP);
+		    while(ok && c--) {
+		      ok &= CGOColorv(I->shaderCGO, vc);
+		      vc += 3;
+		      if (ok){
+			ok &= CGOVertexv(I->shaderCGO, v);
+			v += 3;
+		      }
+		    }
+		    if (ok)
+		      ok &= CGOEnd(I->shaderCGO);
 		  }
-		} else {
-		  CGOBegin(I->shaderCGO, GL_LINE_STRIP);
-		  while(c--) {
-		    CGOColorv(I->shaderCGO, vc);
-		    vc += 3;
-		    CGOVertexv(I->shaderCGO, v);
-		    v += 3;
-		  }
-		  CGOEnd(I->shaderCGO);
 		}
 	      }
 	    }
 	  } else {
 	    if(I->oneColorFlag) {
 	      while(*n) {
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
 		glColor3fv(ColorGet(G, I->oneColor));
-#endif
 		c = *(n++);
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
 #ifdef _PYMOL_GL_DRAWARRAYS
 		{
 		  int nverts = c, pl;		  
@@ -389,15 +400,11 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
 		  v += 3;
 		}
 		glEnd();
-#endif
 #endif
 	      }
 	    } else {
 	      while(*n) {
 		c = *(n++);
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
 #ifdef _PYMOL_GL_DRAWARRAYS
 		{
 		  int nverts = c, pl, plc = 0;		  
@@ -429,7 +436,6 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
 		  v += 3;
 		}
 		glEnd();
-#endif
 #endif
 	      }
 	    }
@@ -437,60 +443,51 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
 	}
 	break;
       case 1:
-#ifdef PURE_OPENGL_ES_2
-    /* TODO */
-#else
 	glPointSize(SettingGet_f
 		    (G, I->R.cs->Setting, I->R.obj->Setting, cSetting_dot_width));
-#endif
-	if(n) {
+	if(ok && n) {
 	  if (generate_shader_cgo){
 	    if(I->oneColorFlag) {
-	      while(*n) {
-		CGOColorv(I->shaderCGO, ColorGet(G, I->oneColor));
+	      while(ok && *n) {
+		ok &= CGOColorv(I->shaderCGO, ColorGet(G, I->oneColor));
 		c = *(n++);
-		if (!dot_as_spheres)
-		  CGOBegin(I->shaderCGO, GL_POINTS);
-		while(c--) {
+		if (ok && !dot_as_spheres)
+		  ok &= CGOBegin(I->shaderCGO, GL_POINTS);
+		while(ok && c--) {
 		  if (dot_as_spheres)
-		    CGOSphere(I->shaderCGO, v, 1.f);
+		    ok &= CGOSphere(I->shaderCGO, v, 1.f);
 		  else
-		    CGOVertexv(I->shaderCGO, v);
+		    ok &= CGOVertexv(I->shaderCGO, v);
 		  v += 3;
 		}
-		if (!dot_as_spheres)
-		  CGOEnd(I->shaderCGO);
+		if (ok && !dot_as_spheres)
+		  ok &= CGOEnd(I->shaderCGO);
 	      }
 	    } else {
-	      while(*n) {
+	      while(ok && *n) {
 		c = *(n++);
 		if (!dot_as_spheres)
-		  CGOBegin(I->shaderCGO, GL_POINTS);
-		while(c--) {
-		  CGOColorv(I->shaderCGO, vc);
+		  ok &= CGOBegin(I->shaderCGO, GL_POINTS);
+		while(ok && c--) {
+		  ok &= CGOColorv(I->shaderCGO, vc);
 		  vc += 3;
-		  if (dot_as_spheres)
-		    CGOSphere(I->shaderCGO, v, 1.f);
-		  else
-		    CGOVertexv(I->shaderCGO, v);
+		  if (ok){
+		    if (dot_as_spheres)
+		      ok &= CGOSphere(I->shaderCGO, v, 1.f);
+		    else
+		      ok &= CGOVertexv(I->shaderCGO, v);
+		  }
 		  v += 3;
 		}
 		if (!dot_as_spheres)
-		  CGOEnd(I->shaderCGO);
+		  ok &= CGOEnd(I->shaderCGO);
 	      }
 	    }
 	  } else {
 	    if(I->oneColorFlag) {
 	      while(*n) {
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
 		glColor3fv(ColorGet(G, I->oneColor));
-#endif
 		c = *(n++);
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
 #ifdef _PYMOL_GL_DRAWARRAYS
 		{
 		  int nverts = c, pl;		  
@@ -513,15 +510,11 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
 		  v += 3;
 		}
 		glEnd();
-#endif
 #endif
 	      }
 	    } else {
 	      while(*n) {
 		c = *(n++);
-#ifdef PURE_OPENGL_ES_2
-		/* TODO */
-#else
 #ifdef _PYMOL_GL_DRAWARRAYS
 		{
 		  int nverts = c, pl, plc = 0;		  
@@ -553,7 +546,6 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
 		  v += 3;
 		}
 		glEnd();
-#endif
 #endif
 	      }
 	    }
@@ -564,37 +556,44 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
       
       /* end of rendering, if using shaders, then render CGO */
       if (use_shader) {
-	if (generate_shader_cgo){
+	if (ok && generate_shader_cgo){
 	  CGO *convertcgo = NULL;
-	  CGOStop(I->shaderCGO);
+	  ok &= CGOStop(I->shaderCGO);
 #ifdef _PYMOL_CGO_DRAWARRAYS
-	  convertcgo = CGOCombineBeginEnd(I->shaderCGO, 0);    
+	  if (ok)
+	    convertcgo = CGOCombineBeginEnd(I->shaderCGO, 0);    
+	  CHECKOK(ok, convertcgo);
 	  CGOFree(I->shaderCGO);    
 	  I->shaderCGO = convertcgo;
+	  convertcgo = NULL;
 #else
 	  (void)convertcgo;
 #endif
 #ifdef _PYMOL_CGO_DRAWBUFFERS
-	  if (dot_as_spheres){
-	    convertcgo = CGOOptimizeSpheresToVBONonIndexed(I->shaderCGO, CGO_BOUNDING_BOX_SZ + CGO_DRAW_SPHERE_BUFFERS_SZ);	    
-	  } else {
-	    if (mesh_as_cylinders){
-	      convertcgo = CGOOptimizeGLSLCylindersToVBOIndexed(I->shaderCGO, 0);
+	  if (ok){
+	    if (dot_as_spheres){
+	      convertcgo = CGOOptimizeSpheresToVBONonIndexed(I->shaderCGO, CGO_BOUNDING_BOX_SZ + CGO_DRAW_SPHERE_BUFFERS_SZ);	    
 	    } else {
-	      convertcgo = CGOOptimizeToVBOIndexed(I->shaderCGO, 0);
+	      if (mesh_as_cylinders){
+		convertcgo = CGOOptimizeGLSLCylindersToVBOIndexed(I->shaderCGO, 0);
+	      } else {
+		convertcgo = CGOOptimizeToVBONotIndexed(I->shaderCGO, 0);
+	      }
 	    }
+	    CHECKOK(ok, convertcgo);
 	  }
 	  if (convertcgo){
 	    convertcgo->use_shader = true;
 	    CGOFree(I->shaderCGO);
 	    I->shaderCGO = convertcgo;
+	    convertcgo = NULL;
 	  }
 #else
 	  (void)convertcgo;
 #endif
 	}
 	
-	{
+	if (ok){
 	  CShaderPrg *shaderPrg;
 	  if (dot_as_spheres){
 	    float pixel_scale_value = SettingGetGlobal_f(G, cSetting_ray_pixel_scale);
@@ -602,7 +601,7 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
 	    if(pixel_scale_value < 0)
 	      pixel_scale_value = 1.0F;    
 	    radius = info->vertex_scale * pixel_scale_value * line_width/ 2.f;
-	    shaderPrg = CShaderPrg_Enable_SphereShader(G, "sphere");
+	    shaderPrg = CShaderPrg_Enable_DefaultSphereShader(G);
 	    CShaderPrg_Set1f(shaderPrg, "sphere_size_scale", radius);
 	  } else {
 	    if (mesh_as_cylinders){
@@ -610,10 +609,11 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
 	      CShaderPrg_Set1f(shaderPrg, "uni_radius", SceneGetLineWidthForCylinders(G, info, mesh_width));
 	    } else {
 	      shaderPrg = CShaderPrg_Enable_DefaultShader(G);
-	      CShaderPrg_Set1i(shaderPrg, "lighting_enabled", 1);
+	      CShaderPrg_SetLightingEnabled(shaderPrg, 1);
 	      CShaderPrg_Set1i(shaderPrg, "two_sided_lighting_enabled", SceneGetTwoSidedLighting(G));
 	    }
 	  }
+	  if (!shaderPrg) return;
 	  {
 	    float *color;
 	    color = ColorGet(G, I->R.obj->Color);
@@ -630,14 +630,16 @@ static void RepMeshRender(RepMesh * I, RenderInfo * info)
       }
 #endif
 
-#ifdef PURE_OPENGL_ES_2
-    /* TODO */
-#else
       if(!lighting)
         glEnable(GL_LIGHTING);
-#endif
     }
   }
+  if (!ok){
+    CGOFree(I->shaderCGO);
+    I->shaderCGO = NULL;
+    I->R.fInvalidate(&I->R, I->R.cs, cRepInvPurge);
+    I->R.cs->Active[cRepMesh] = false;
+  }
 }
 
 int RepMeshSameVis(RepMesh * I, CoordSet * cs)
@@ -843,23 +845,27 @@ Rep *RepMeshNew(CoordSet * cs, int state)
   AtomInfoType *ai1;
 
   OOAlloc(G, RepMesh);
+  CHECKOK (ok, I);
   PRINTFD(G, FB_RepMesh)
   " RepMeshNew-DEBUG: entered with coord-set %p\n", (void *) cs ENDFD;
-  obj = cs->Obj;
-  I->R.context.object = (void *) obj;
-  I->R.context.state = state;
-
-  probe_radius = SettingGet_f(G, cs->Setting, obj->Obj.Setting, cSetting_solvent_radius);
-  probe_radius2 = probe_radius * probe_radius;
-  solv_acc = (SettingGet_i(G, cs->Setting, obj->Obj.Setting, cSetting_mesh_solvent));
-  mesh_type = SettingGet_i(G, cs->Setting, obj->Obj.Setting, cSetting_mesh_type);
-  mesh_skip = SettingGet_i(G, cs->Setting, obj->Obj.Setting, cSetting_mesh_skip);
-
-  mesh_mode = SettingGet_i(G, cs->Setting, obj->Obj.Setting, cSetting_mesh_mode);
-  cullByFlag = (mesh_mode == cRepMesh_by_flags);
-  inclH = !(mesh_mode == cRepMesh_heavy_atoms);
+  if (ok){
+    obj = cs->Obj;
+    I->R.context.object = (void *) obj;
+    I->R.context.state = state;
+  }
+  if (ok){
+    probe_radius = SettingGet_f(G, cs->Setting, obj->Obj.Setting, cSetting_solvent_radius);
+    probe_radius2 = probe_radius * probe_radius;
+    solv_acc = (SettingGet_i(G, cs->Setting, obj->Obj.Setting, cSetting_mesh_solvent));
+    mesh_type = SettingGet_i(G, cs->Setting, obj->Obj.Setting, cSetting_mesh_type);
+    mesh_skip = SettingGet_i(G, cs->Setting, obj->Obj.Setting, cSetting_mesh_skip);
+    
+    mesh_mode = SettingGet_i(G, cs->Setting, obj->Obj.Setting, cSetting_mesh_mode);
+    cullByFlag = (mesh_mode == cRepMesh_by_flags);
+    inclH = !(mesh_mode == cRepMesh_heavy_atoms);
+  }
   visFlag = false;
-  if(obj->RepVisCache[cRepMesh])
+  if(ok && obj->RepVisCache[cRepMesh]){
     for(a = 0; a < cs->NIndex; a++) {
       ai1 = obj->AtomInfo + cs->IdxToAtm[a];
       if(ai1->visRep[cRepMesh] &&
@@ -869,7 +875,8 @@ Rep *RepMeshNew(CoordSet * cs, int state)
         break;
       }
     }
-  if(!visFlag) {
+  }
+  if(!ok || !visFlag) {
     OOFreeP(I);
     return (NULL);              /* skip if no dots are visible */
   }
@@ -934,14 +941,16 @@ Rep *RepMeshNew(CoordSet * cs, int state)
     if(trim_cutoff > 0.0F) {
       int nc = 0;
       trim_vla = VLAlloc(float, cs->NIndex * 3);
-      for(c = 0; c < cs->NIndex; c++) {
+      CHECKOK(ok, trim_vla);
+      for(c = 0; ok && c < cs->NIndex; c++) {
         ai1 = obj->AtomInfo + cs->IdxToAtm[c];
         if(ai1->visRep[cRepMesh] &&
            (inclH || (!ai1->hydrogen)) &&
            ((!cullByFlag) ||
             (!(ai1->flags & (cAtomFlag_ignore | cAtomFlag_exfoliate))))) {
           VLACheck(trim_vla, float, nc * 3 + 2);
-          {
+	  CHECKOK(ok, trim_vla);
+          if (ok) {
             float *src = cs->Coord + 3 * c;
             float *dst = trim_vla + 3 * nc;
             *(dst++) = *(src++);
@@ -951,16 +960,17 @@ Rep *RepMeshNew(CoordSet * cs, int state)
           }
         }
       }
-      if(nc) {
+      if(ok && nc) {
         trim_map = MapNew(G, trim_cutoff, trim_vla, nc, NULL);
-        if(trim_map) {
-          MapSetupExpress(trim_map);
+	CHECKOK(ok, trim_map);
+        if(ok) {
+          ok &= MapSetupExpress(trim_map);
           trim_flag = true;
         }
       }
     }
 
-    if(carve_cutoff > 0.0F) {
+    if(ok && carve_cutoff > 0.0F) {
       carve_state =
         SettingGet_i(G, cs->Setting, obj->Obj.Setting, cSetting_mesh_carve_state) - 1;
       carve_selection =
@@ -972,11 +982,11 @@ Rep *RepMeshNew(CoordSet * cs, int state)
                                                        carve_state, carve_cutoff,
                                                        &carve_vla);
       if(carve_map) {
-        MapSetupExpress(carve_map);
+        ok &= MapSetupExpress(carve_map);
         carve_flag = true;
       }
     }
-    if(clear_cutoff > 0.0F) {
+    if(ok && clear_cutoff > 0.0F) {
       clear_state =
         SettingGet_i(G, cs->Setting, obj->Obj.Setting, cSetting_mesh_clear_state) - 1;
       clear_selection =
@@ -988,88 +998,93 @@ Rep *RepMeshNew(CoordSet * cs, int state)
                                                        clear_state, clear_cutoff,
                                                        &clear_vla);
       if(clear_map) {
-        MapSetupExpress(clear_map);
+        ok &= MapSetupExpress(clear_map);
         clear_flag = true;
       }
     }
 
-    I->V = VLAMalloc(1000, sizeof(float), 9, false);
-    I->N = VLAMalloc(100, sizeof(int), 9, false);
+    if (ok)
+      I->V = (float*) VLAMalloc(1000, sizeof(float), 9, false);
+    CHECKOK(ok, I->V);
+    if (ok)
+      I->N = (int*) VLAMalloc(100, sizeof(int), 9, false);
+    CHECKOK(ok, I->N);
+    if (ok)
+      I->N[0] = 0;
 
-    I->N[0] = 0;
-
-    for(c = 0; c < 3; c++) {
-      /*                  minE[c]=(cs->Obj->Obj.extent[2*c]-MAX_VDW)-0.25;
-         maxE[c]=(cs->Obj->Obj.extent[2*c+1]+MAX_VDW)+0.25;
-       */
-      minE[c] = MAXFLOAT;
-      maxE[c] = -(MAXFLOAT);
-    }
-
-    for(b = 0; b < obj->NCSet; b++) {
-      ccs = obj->CSet[b];
-      if(ccs) {
-        for(c = 0; c < ccs->NIndex; c++) {
-          ai1 = obj->AtomInfo + ccs->IdxToAtm[c];       /* WLD fixed 011218 */
-          if(ai1->visRep[cRepMesh] &&
-             (inclH || (!ai1->hydrogen)) &&
-             ((!cullByFlag) ||
-              (!(ai1->flags & (cAtomFlag_ignore | cAtomFlag_exfoliate))))) {
-            for(d = 0; d < 3; d++) {
-              if(minE[d] > ccs->Coord[(3 * c) + d])
-                minE[d] = ccs->Coord[(3 * c) + d];
-              if(maxE[d] < ccs->Coord[(3 * c) + d])
-                maxE[d] = ccs->Coord[(3 * c) + d];
-            }
-          }
-        }
+    if (ok){
+      for(c = 0; c < 3; c++) {
+	minE[c] = MAXFLOAT;
+	maxE[c] = -(MAXFLOAT);
+      }
+      for(b = 0; b < obj->NCSet; b++) {
+	ccs = obj->CSet[b];
+	if(ccs) {
+	  for(c = 0; c < ccs->NIndex; c++) {
+	    ai1 = obj->AtomInfo + ccs->IdxToAtm[c];       /* WLD fixed 011218 */
+	    if(ai1->visRep[cRepMesh] &&
+	       (inclH || (!ai1->hydrogen)) &&
+	       ((!cullByFlag) ||
+		(!(ai1->flags & (cAtomFlag_ignore | cAtomFlag_exfoliate))))) {
+	      for(d = 0; d < 3; d++) {
+		if(minE[d] > ccs->Coord[(3 * c) + d])
+		  minE[d] = ccs->Coord[(3 * c) + d];
+		if(maxE[d] < ccs->Coord[(3 * c) + d])
+		  maxE[d] = ccs->Coord[(3 * c) + d];
+	      }
+	    }
+	  }
+	}
+      }
+      for(c = 0; c < 3; c++) {
+	minE[c] -= (float) (I->max_vdw + 0.25F);
+	maxE[c] += (float) (I->max_vdw + 0.25F);
       }
     }
 
-    for(c = 0; c < 3; c++) {
-      minE[c] -= (float) (I->max_vdw + 0.25F);
-      maxE[c] += (float) (I->max_vdw + 0.25F);
+    if (ok){
+      subtract3f(maxE, minE, sizeE);
+      
+      size = sizeE[0];
+      if(sizeE[1] > size)
+	size = sizeE[1];
+      if(sizeE[2] > size)
+	size = sizeE[2];
+      
+      gridSize = size / mesh_max; /* grid size is the largest axis divided by 25 */
+      
+      if(gridSize < min_spacing)
+	gridSize = min_spacing;
+      
+      for(c = 0; c < 3; c++)
+	dims[c] = (int) ((sizeE[c] / gridSize) + 1.5F);
+      field = IsosurfFieldAlloc(G, dims);
+      CHECKOK(ok, field);
     }
 
-    subtract3f(maxE, minE, sizeE);
-
-    size = sizeE[0];
-    if(sizeE[1] > size)
-      size = sizeE[1];
-    if(sizeE[2] > size)
-      size = sizeE[2];
-
-    gridSize = size / mesh_max; /* grid size is the largest axis divided by 25 */
-
-    if(gridSize < min_spacing)
-      gridSize = min_spacing;
-
-    for(c = 0; c < 3; c++)
-      dims[c] = (int) ((sizeE[c] / gridSize) + 1.5F);
-
-    field = IsosurfFieldAlloc(G, dims);
-
-    for(a = 0; a < dims[0]; a++)
-      for(b = 0; b < dims[1]; b++)
-        for(c = 0; c < dims[2]; c++)
-          F3(field->data, a, b, c) = 2.0;
-
+    if (ok){
+      for(a = 0; a < dims[0]; a++)
+	for(b = 0; b < dims[1]; b++)
+	  for(c = 0; c < dims[2]; c++)
+	    F3(field->data, a, b, c) = 2.0;
+    }
     OrthoBusyFast(G, 0, 1);
-    if(!solv_acc)
-      ok = RepMeshGetSolventDots(I, cs, minE, maxE, probe_radius);
+    if(ok && !solv_acc)
+      ok &= RepMeshGetSolventDots(I, cs, minE, maxE, probe_radius);
     if(ok) {
       smap = MapNew(G, probe_radius, I->Dot, I->NDot, NULL);
       map = MapNew(G, I->max_vdw + probe_radius, cs->Coord, cs->NIndex, NULL);
     }
     if(ok && map && smap) {
-      MapSetupExpress(smap);
-      MapSetupExpress(map);
-      for(a = 0; a < dims[0]; a++) {
+      ok &= MapSetupExpress(smap);
+      if (ok)
+	ok &= MapSetupExpress(map);
+      for(a = 0; ok && a < dims[0]; a++) {
         OrthoBusyFast(G, dims[0] + a, dims[0] * 3);
         point[0] = minE[0] + a * gridSize;
-        for(b = 0; b < dims[1]; b++) {
+        for(b = 0; ok && b < dims[1]; b++) {
           point[1] = minE[1] + b * gridSize;
-          for(c = 0; c < dims[2]; c++) {
+          for(c = 0; ok && c < dims[2]; c++) {
             float bestDist;
             float dist2vdw;
             float vdw_add = solv_acc * probe_radius;
@@ -1082,7 +1097,7 @@ Rep *RepMeshNew(CoordSet * cs, int state)
             d = *(MapEStart(map, h, k, l));
             if(d) {
               cur = map->EList[d++];
-              while(cur >= 0) {
+              while(ok && cur >= 0) {
                 ai1 = obj->AtomInfo + cs->IdxToAtm[cur];
                 if((inclH || (!ai1->hydrogen)) &&
                    ((!cullByFlag) || (!(ai1->flags & cAtomFlag_ignore)))) {
@@ -1095,9 +1110,10 @@ Rep *RepMeshNew(CoordSet * cs, int state)
                   }
                 }
                 cur = map->EList[d++];
+		ok &= !G->Interrupt;
               }
             }
-            if(aNear >= 0) {    /* near an atom... */
+            if(ok && aNear >= 0) {    /* near an atom... */
               pVal = aLen;      /* pVal is the distance from atom center */
               vdw = cs->Obj->AtomInfo[cs->IdxToAtm[aNear]].vdw + solv_acc * probe_radius;
               if((!solv_acc) && (pVal > vdw) && (pVal < (vdw + probe_radius))) {        /* point outside an atom */
@@ -1140,12 +1156,12 @@ Rep *RepMeshNew(CoordSet * cs, int state)
               if(pVal < F3(field->data, a, b, c))
                 F3(field->data, a, b, c) = pVal;
             }
+	    ok &= !G->Interrupt;
           }
         }
-        if(G->Interrupt) {
-          ok = false;
-          break;
-        }
+	ok &= !G->Interrupt;
+	if (!ok)
+	  break;
       }
     }
     MapFree(smap);
@@ -1153,11 +1169,12 @@ Rep *RepMeshNew(CoordSet * cs, int state)
     FreeP(I->Dot);
     OrthoBusyFast(G, 2, 3);
     if(ok) {
-      IsosurfVolume(G, NULL, NULL, field, 1.0, &I->N, &I->V, NULL, mesh_type, mesh_skip,
+      ok &= IsosurfVolume(G, NULL, NULL, field, 1.0, &I->N, &I->V, NULL, mesh_type, mesh_skip,
                     1.0F);
     }
-    IsosurfFieldFree(G, field);
-    if(I->N && I->V && (carve_flag || clear_flag || trim_flag)) {
+    if (field)
+      IsosurfFieldFree(G, field);
+    if(ok && (I->N && I->V && (carve_flag || clear_flag || trim_flag))) {
       int cur_size = VLAGetSize(I->N);
       if((mesh_type == 0) && cur_size) {
         int *n = I->N;
@@ -1165,7 +1182,8 @@ Rep *RepMeshNew(CoordSet * cs, int state)
         int new_size = 0;
         float *new_v = I->V;
         float *v = I->V;
-        while((c = *(n++))) {
+	CHECKOK(ok, new_n);
+        while(ok && (c = *(n++))) {
           int new_c = 0;
           float *last_v = NULL;
           while(c--) {
@@ -1242,14 +1260,18 @@ Rep *RepMeshNew(CoordSet * cs, int state)
               v += 3;
               if(new_c) {
                 VLACheck(new_n, int, new_size + 1);     /* extends the zero count sentinel */
-                new_n[new_size] = new_c;
-                new_size++;
-                new_c = 0;
+		CHECKOK(ok, new_n);
+		if (ok){
+		  new_n[new_size] = new_c;
+		  new_size++;
+		  new_c = 0;
+		}
               }
             }
           }
-          if(new_c) {
+          if(ok && new_c) {
             VLACheck(new_n, int, new_size + 1); /* extends the zero count sentinel */
+	    CHECKOK(ok, new_n);
             new_n[new_size] = new_c;
             new_size++;
             new_c = 0;
@@ -1267,13 +1289,19 @@ Rep *RepMeshNew(CoordSet * cs, int state)
     VLAFreeP(clear_vla);
     n = I->N;
     I->NTot = 0;
-    while(*n)
-      I->NTot += *(n++);
-    RepMeshColor(I, cs);
+    if (ok){
+      while(*n)
+	I->NTot += *(n++);
+      RepMeshColor(I, cs);
+    }
     OrthoBusyFast(G, 3, 4);
   }
   OrthoBusyFast(G, 4, 4);
-  return ((void *) (struct Rep *) I);
+  if(!ok) {
+    RepMeshFree(I);
+    I = NULL;
+  }
+  return (Rep *) I;
 }
 
 int RepMeshGetSolventDots(RepMesh * I, CoordSet * cs, float *min, float *max,
@@ -1376,8 +1404,8 @@ int RepMeshGetSolventDots(RepMesh * I, CoordSet * cs, float *min, float *max,
           maxDot = I->NDot - 1;
         }
       }
-      if(G->Interrupt) {
-        ok = false;
+      ok &= !G->Interrupt;
+      if(!ok) {
         break;
       }
     }
@@ -1432,10 +1460,10 @@ int RepMeshGetSolventDots(RepMesh * I, CoordSet * cs, float *min, float *max,
           v += 3;
           p++;
         }
-        if(G->Interrupt) {
-          ok = false;
-          break;
-        }
+	ok &= !G->Interrupt;
+	if(!ok) {
+	  break;
+	}
       }
       MapFree(map);
     }
