@@ -22,6 +22,10 @@ Z* -------------------------------------------------------------------
 #include "ObjectMolecule.h"
 #include "ObjectMap.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int PlugIOManagerInit(PyMOLGlobals * G);
 int PlugIOManagerFree(PyMOLGlobals * G);
 int PlugIOManagerLoadTraj(PyMOLGlobals * G, ObjectMolecule * obj,
@@ -32,4 +36,8 @@ int PlugIOManagerLoadTraj(PyMOLGlobals * G, ObjectMolecule * obj,
 ObjectMap *PlugIOManagerLoadVol(PyMOLGlobals * G, ObjectMap * obj,
                                 char *fname, int state, int quiet, char *plugin_type);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
