@@ -686,8 +686,8 @@ def compute(self_cmd, sele):
                ]],
             [ 1, 'surface area',
               [[ 2, 'Surface Area Type:', ''],
-               [ 1, 'molecular', 'cmd.get_area("'+sele+'",quiet=0,_self=cmd)' ],
-               [ 1, 'solvent accessible', 'util.get_sasa(sele="'+sele+'",_self=cmd)' ],
+               [ 1, 'molecular', 'util.get_area("'+sele+'", -1, 0, quiet=0,_self=cmd)' ],
+               [ 1, 'solvent accessible', 'util.get_sasa("'+sele+'",quiet=0,_self=cmd)' ],
                ]],
             [ 1, 'molecular weight',
               [[ 2, 'Molecular Weight:', ''],
