@@ -35,16 +35,28 @@ if __name__=='pymol.querying':
                     _self.distance()
         _self.unpick()   
 
-    def get_volume_field(objName,_self=cmd):
+    def get_volume_field(objName, state=1, _self=cmd):
+        '''
+DESCRIPTION
+
+    EXPERIMENTAL AND SUBJECT TO CHANGE - DO NOT USE
+    Get the raw data of a map or volume object.
+        '''
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)
-            r = _self._cmd.get_volume_field(_self._COb,objName)
+            r = _self._cmd.get_volume_field(_self._COb, objName, int(state) - 1)
         finally:
             _self.unlock(r,_self)
         return r
 
     def get_volume_histogram(objName, bins=64, range=None, _self=cmd):
+        '''
+DESCRIPTION
+
+    API ONLY.  Get min, max, mean, stdev and histogram of a map or volume
+    object as a list of length bins + 4.
+        '''
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)
@@ -55,13 +67,8 @@ if __name__=='pymol.querying':
         return r
 
     def get_volume_is_updated(objName,_self=cmd):
-        r = DEFAULT_ERROR
-        try:
-            _self.lock(_self)
-            r = _self._cmd.get_volume_is_updated(_self._COb,objName)
-        finally:
-            _self.unlock(r,_self)
-        return r
+        print ' DEPRECATED: get_volume_is_updated'
+        return 1
  
     def get_unused_name(prefix="tmp",alwaysnumber=1,_self=cmd):
         r = DEFAULT_ERROR        
@@ -1524,4 +1531,53 @@ DESCRIPTION
             raise pymol.CmdException('Selection spans multiple object states')
         return state_set.pop()
 
+    def centerofmass(selection='(all)', state=-1, quiet=1, _self=cmd):
+        '''
+DESCRIPTION
+
+    Calculates the center of mass. Considers atom mass and occupancy.
+
+ARGUMENTS
+
+    selection = string: atom selection {default: all}
+
+    state = integer: object state, -1 for current state, 0 for all states
+    {default: -1}
+
+NOTES
+
+    If occupancy is 0.0 for an atom, set it to 1.0 for the calculation
+    (assume it was loaded from a file without occupancy information).
+
+SEE ALSO
+
+    get_extent
+        '''
+        from chempy import cpv
+        state, quiet = int(state), int(quiet)
+
+        if state < 0:
+            states = [get_selection_state(selection)]
+        elif state == 0:
+            states = range(1, _self.count_states(selection)+1)
+        else:
+            states = [state]
+
+        com = cpv.get_null()
+        totmass = 0.0
+
+        for state in states:
+            model = _self.get_model(selection, state)
+            for a in model.atom:
+                m = a.get_mass() * (a.q or 1.0)
+                com = cpv.add(com, cpv.scale(a.coord, m))
+                totmass += m
+
+        if not totmass:
+            raise pymol.CmdException('mass is zero')
+
+        com = cpv.scale(com, 1./totmass)
+        if not quiet:
+            print ' Center of Mass: [%8.3f,%8.3f,%8.3f]' % tuple(com)
+        return com
 
